- 1.0.0 — First release. Added `include`, `env`, `random_int`, `random_float`, 
          `random_str` and `time_now` tags. 

- 1.0.1 - Added `readme.md` and `contributing.md` files. 
          Changed `authors.md` and `changelog.md` files